==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteActionRewritePathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact path to match on.
 */
public data class GatewayRouteSpecHttpRouteActionRewritePathArgs(
    public val exact: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs.builder()
            .exact(exact.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteActionRewritePathArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteActionRewritePathArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value The exact path to match on.
     */
    @JvmName("kopxhpyrrgpcxxay")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The exact path to match on.
     */
    @JvmName("hpgdcincnlciemno")
    public suspend fun exact(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteActionRewritePathArgs =
        GatewayRouteSpecHttpRouteActionRewritePathArgs(
            exact = exact ?: throw PulumiNullFieldException("exact"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteActionRewritePathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact path to match on.
 */
public data class GatewayRouteSpecHttpRouteActionRewritePathArgs(
    public val exact: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePathArgs.builder()
            .exact(exact.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteActionRewritePathArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteActionRewritePathArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value The exact path to match on.
     */
    @JvmName("vufrcueniftwifpr")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The exact path to match on.
     */
    @JvmName("tecdthbdbdarlmwv")
    public suspend fun exact(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteActionRewritePathArgs =
        GatewayRouteSpecHttpRouteActionRewritePathArgs(
            exact = exact ?: throw PulumiNullFieldException("exact"),
        )
}
